bump_pointer_press_epoch

Function bump_pointer_press_epoch 

pub fn bump_pointer_press_epoch()
Advance the pointer-press epoch. Called by App once per pointer press that is about to be routed into the widget tree.