pub struct Settings {
pub max_undos: usize,
pub stable_time: f32,
pub auto_save_interval: f32,
}Expand description
Tuning knobs for Undoer. Mirrors egui’s Settings.
Fields
max_undos: usizeMaximum number of undo points retained.
stable_time: f32Once the state has been unchanged for this many seconds, create a new undo point (if one is needed).
auto_save_interval: f32If the state keeps changing and never stabilises, still create a save point every this many seconds so there is always something to undo to.