pub struct Undoer<State> { /* private fields */ }Expand description
Automatic undo system. Feed it the latest state every frame; it decides when to snapshot a new undo point.
Implementations
Sourceimpl<State> Undoer<State>
impl<State> Undoer<State>
Sourcepub fn with_settings(settings: Settings) -> Self
pub fn with_settings(settings: Settings) -> Self
Sourcepub fn has_undo(&self, current_state: &State) -> bool
pub fn has_undo(&self, current_state: &State) -> bool
Do we have an undo point different from the given state?
Sourcepub fn has_redo(&self, current_state: &State) -> bool
pub fn has_redo(&self, current_state: &State) -> bool
Do we have a redo point available for the given state?
Sourcepub fn is_in_flux(&self) -> bool
pub fn is_in_flux(&self) -> bool
Is the state currently mid-change (a flux is being tracked)?
Sourcepub fn undo(&mut self, current_state: &State) -> Option<&State>
pub fn undo(&mut self, current_state: &State) -> Option<&State>
Undo one step, returning the state to revert to (if any).
Sourcepub fn redo(&mut self, current_state: &State) -> Option<&State>
pub fn redo(&mut self, current_state: &State) -> Option<&State>
Redo one step, returning the state to advance to (if any).
Sourcepub fn add_undo(&mut self, current_state: &State)
pub fn add_undo(&mut self, current_state: &State)
Add an undo point iff the state differs from the latest point.
Sourcepub fn feed_state(&mut self, current_time: f64, current_state: &State)
pub fn feed_state(&mut self, current_time: f64, current_state: &State)
Feed the most recent state (call every frame). current_time is in
seconds. Implements the two coalescing rules described on egui’s
Undoer.