pub struct CompositingLayer {
pub outset_left: f64,
pub outset_bottom: f64,
pub outset_right: f64,
pub outset_top: f64,
pub alpha: f64,
}Expand description
Offscreen compositing layer requested by a widget for itself and its descendants.
Fields
outset_left: f64Extra transparent pixels to the left of the widget bounds.
outset_bottom: f64Extra transparent pixels below the widget bounds.
outset_right: f64Extra transparent pixels to the right of the widget bounds.
outset_top: f64Extra transparent pixels above the widget bounds.
alpha: f64Whole-layer opacity applied while compositing back to the parent.
Implementations