pub struct InspectorOverlay {
pub bounds: Rect,
pub margin: Insets,
pub padding: Insets,
}Expand description
Snapshot pushed to the platform render loop so the host can draw a Chrome F12-style three-band overlay (margin + bounds + padding) around the widget the inspector is hovering.
Fields
bounds: Rectmargin: Insetspadding: InsetsTrait Implementations
Sourceimpl Clone for InspectorOverlay
impl Clone for InspectorOverlay
Sourcefn clone(&self) -> InspectorOverlay
fn clone(&self) -> InspectorOverlay
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InspectorOverlay
impl Debug for InspectorOverlay
Sourceimpl PartialEq for InspectorOverlay
impl PartialEq for InspectorOverlay
Sourcefn eq(&self, other: &InspectorOverlay) -> bool
fn eq(&self, other: &InspectorOverlay) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for InspectorOverlay
impl StructuralPartialEq for InspectorOverlay