Module conditional
agg_gui
0.2.0
Module conditional
Module Items
Structs
In agg_
gui::
widgets
agg_gui
::
widgets
Module
conditional
Conditional — show/hide a single child based on an external Cell
.
Structs

Conditional
Wrap a single child widget; show or hide it based on a shared boolean.