Reusable menu infrastructure.
This module provides the shared model, geometry, state, painter, and widget adapters used by context menus and top menu bars.
Re-exports
pub use geometry::BAR_H as MENU_BAR_H;pub use geometry::MENU_W;pub use geometry::ROW_H;pub use model::MenuEntry;pub use model::MenuItem;pub use model::MenuSelection;pub use model::MenuShortcut;pub use model::ShortcutKey;pub use paint::MenuStyle;pub use state::MenuAnchorKind;pub use state::MenuResponse;pub use state::PopupMenuState;pub use strip::MenuBarStrip;pub use widget::MenuBar;pub use widget::MenuOrientation;pub use widget::PopupMenu;pub use widget::TopMenu;pub use widget::VERTICAL_ROW_H;
Modules
- geometry
- Y-up menu geometry and hit testing.
- model
- Data model for popup and menu-bar menus.
- paint
- Themed painting for popup menus and menu bars.
- state
- Open menu state and event-side behavior.
- strip
MenuBarStrip— full-width top-of-window strip that auto-sizes its height to the wrapped child’s natural height.- widget
- Widget adapters for reusable menus.