Module geometry

Module geometry 

Y-up menu geometry and hit testing.

Popup menus are global overlays, so geometry is expressed in the owning widget’s local coordinate space but clamped against the current viewport.

Structs

PopupLayout
RowLayout

Enums

MenuHit

Constants

BAR_H
MENU_W
ROW_H
SEP_H

Functions

contains
hit_test
item_at
item_at_path
popup_height
stack_layout