Widget adapters for reusable menus.
ContextMenu is a small controller that other widgets can embed, while
MenuBar is a visible widget for top-level menus.
Structs
Enums
- Menu
Orientation - Layout direction for
MenuBar.
Widget adapters for reusable menus.
ContextMenu is a small controller that other widgets can embed, while
MenuBar is a visible widget for top-level menus.
MenuBar.