split_block

Function split_block 

pub fn split_block(doc: &mut RichDoc, pos: DocPos) -> DocPos
Split the block at pos into two paragraphs (Enter semantics). The new block inherits the original’s alignment, list kind, and indent. Returns the position at the start of the new block.