pub struct LcdGfxCtx<'a> { /* private fields */ }Expand description
Cairo-style stateful 2D graphics context whose render target is an
LcdBuffer. Borrows the buffer mutably for the lifetime of the
ctx; let the ctx drop and the buffer is free to be uploaded /
composited / read.
Implementations