pub struct TextMetrics {
pub width: f64,
pub ascent: f64,
pub descent: f64,
pub line_height: f64,
}Expand description
Metrics describing a single line of shaped text.
Fields
width: f64Advance width of the text run in pixels.
ascent: f64Distance from baseline to top of tallest ascender, in pixels (positive).
descent: f64Distance from baseline to bottom of deepest descender, in pixels (positive).
line_height: f64Recommended line height (ascender + descender + line gap), in pixels.
Implementations
Sourceimpl TextMetrics
impl TextMetrics
Sourcepub fn centered_baseline_y(&self, height: f64) -> f64
pub fn centered_baseline_y(&self, height: f64) -> f64
Baseline Y that visually centers this text run in a Y-up box.