pub fn set_visuals(v: Visuals)
Replace the active Visuals.
Visuals
Call this once per frame before painting, typically from the platform render loop after reading the user’s ThemePreference.
ThemePreference