Button — a clickable, compositional button with a Label child.
Re-exports
pub use super::button_theme::ButtonTheme;
Structs
- Button
- A clickable button.
- Button
Icon - Icon glyph drawn at the leading edge of a
Button’s label. The glyph is rendered with a separate font so callers can pair e.g. a Font Awesome glyph with a Latin-only text font.