ComboBox — a single-selection dropdown widget.
The widget always occupies its compact closed height. When open, options
are painted as a floating panel below the button in paint_overlay() so
sibling widgets are not pushed down by the dropdown.
Text for the selected value and dropdown items is rendered through
backbuffered Label children maintained in selected_label and
item_labels. Colors are updated from ctx.visuals() in paint() so the
widget responds correctly to dark / light mode switches.
Structs
- Combo
Box - A single-selection dropdown.