Reusable menu infrastructure.
This module provides the shared model, geometry, state, painter, and widget adapters used by context menus and top menu bars.
Re-exports
pub use geometry::BAR_H as MENU_BAR_H;pub use geometry::MENU_W;pub use geometry::ROW_H;pub use model::MenuEntry;pub use model::MenuItem;pub use model::MenuSelection;pub use model::MenuShortcut;pub use model::ShortcutKey;pub use paint::MenuStyle;pub use state::MenuAnchorKind;pub use state::MenuResponse;pub use state::PopupMenuState;pub use widget::MenuBar;pub use widget::PopupMenu;pub use widget::TopMenu;