pub struct Align2 {
pub x: Align,
pub y: Align,
}Expand description
A 2D anchor point within a rectangle (an x and a y Align).
Mirrors egui’s Align2. Remember the Y-up convention: y: Max is the top
edge, y: Min the bottom.
Fields
x: Aligny: AlignImplementations
Sourceimpl Align2
impl Align2
pub const LEFT_TOP: Self
pub const CENTER_TOP: Self
pub const RIGHT_TOP: Self
pub const LEFT_CENTER: Self
pub const CENTER: Self
pub const RIGHT_CENTER: Self
pub const LEFT_BOTTOM: Self
pub const CENTER_BOTTOM: Self
pub const RIGHT_BOTTOM: Self
Sourcepub const ALL: [(Self, &'static str); 9]
pub const ALL: [(Self, &'static str); 9]
All nine anchors with the display names egui’s Popups demo uses, in
the same order its align combo box lists them (left column, center
column, right column). The array index is stable so UI (e.g. a combo
box) can map a selected index straight back to an Align2.
Sourcepub fn all_index(self) -> usize
pub fn all_index(self) -> usize
Index of this anchor within Align2::ALL, or 0 if somehow absent.