pub fn remove_range(doc: &mut RichDoc, range: DocRange) -> DocPosExpand description
Remove everything inside range, preserving the styles of the surviving
text. When the range spans multiple blocks the tail of the last block is
merged into the first (Backspace-across-paragraphs semantics). Returns the
collapse position (the range’s low endpoint).