TabView — a tabbed container with a clickable tab bar.
An optional action button can be placed at the right end of the tab bar.
An optional sidebar widget can be shown to the right of the content area
via [with_sidebar], separated by a draggable vertical divider.
Structs
- TabView
- A tabbed panel container.